@@ -1,5 +1,5 @@
 from .common import AugmentFn
 from .torchaudio import *
 from .transform import AudioTransform
-from .utils import convolve1d
+from .utils import convolve1d, generate_fast_random_rir
 from .wpe import DereverbWPE, dereverb_wpe_torch
