@@ -11,13 +11,16 @@ from .broadcast_news import *
 from .bvcc import *
 from .callhome_egyptian import *
 from .callhome_english import *
+from .chime6 import *
 from .cmu_arctic import *
 from .cmu_indic import *
 from .cmu_kids import *
 from .commonvoice import *
+from .csj import *
 from .cslu_kids import *
 from .daily_talk import *
 from .dihard3 import *
+from .dipco import *
 from .earnings21 import *
 from .earnings22 import *
 from .eval2000 import *
@@ -55,4 +58,5 @@ from .timit import *
 from .vctk import *
 from .voxceleb import *
 from .wenet_speech import *
+from .xbmu_amdo31 import *
 from .yesno import *
