@@ -10,7 +10,9 @@ __all__ = ["ali_meeting"]
 @prepare.command(context_settings=dict(show_default=True))
 @click.argument("corpus_dir", type=click.Path(exists=True, dir_okay=True))
 @click.argument("output_dir", type=click.Path())
-@click.option("--mic", type=click.Choice(["near", "far"]), default="far")
+@click.option(
+    "--mic", type=click.Choice(["near", "far", "ihm", "sdm", "mdm"]), default="far"
+)
 def ali_meeting(corpus_dir: Pathlike, output_dir: Pathlike, mic: str):
     """AliMeeting data preparation."""
     prepare_ali_meeting(corpus_dir, output_dir=output_dir, mic=mic)
