@@ -194,6 +194,11 @@ class DynamicBucketingSampler(CutSampler):
         if self._just_restored_state:
             return self
         self.rng = random.Random(self.seed + self.epoch)
+        # Why reset the current epoch?
+        # Either we are iterating the epoch for the first time and it's a no-op,
+        # or we are iterating the same epoch again, in which case setting more steps
+        # than are actually available per epoch would have broken the checkpoint restoration.
+        self.diagnostics.reset_current_epoch()
         # Initiate iteration
         self.cuts_iter = [iter(cs) for cs in self.cuts]
         # Optionally shuffle
