@@ -17,7 +17,7 @@ from tqdm.auto import tqdm
 from lhotse import validate_recordings_and_supervisions
 from lhotse.audio import Recording, RecordingSet
 from lhotse.supervision import SupervisionSegment, SupervisionSet
-from lhotse.utils import Pathlike, urlretrieve_progress
+from lhotse.utils import Pathlike, safe_extract, urlretrieve_progress
 
 
 def text_normalize(line: str):
@@ -68,12 +68,12 @@ def download_aishell(
             )
         shutil.rmtree(extracted_dir, ignore_errors=True)
         with tarfile.open(tar_path) as tar:
-            tar.extractall(path=corpus_dir)
+            safe_extract(tar, path=corpus_dir)
         if tar_name == dataset_tar_name:
             wav_dir = extracted_dir / "wav"
             for sub_tar_name in os.listdir(wav_dir):
                 with tarfile.open(wav_dir / sub_tar_name) as tar:
-                    tar.extractall(path=wav_dir)
+                    safe_extract(tar, path=wav_dir)
         completed_detector.touch()
 
     return corpus_dir
