@@ -139,7 +139,11 @@ def prepare_cslu_kids(
         logging.info("Writing manifests to JSON files")
         output_dir = Path(output_dir)
         output_dir.mkdir(parents=True, exist_ok=True)
-        manifests["recordings"].to_json(output_dir / "recordings.json")
-        manifests["supervisions"].to_json(output_dir / "supervisions.json")
+        manifests["recordings"].to_file(
+            output_dir / "cslu-kids_recordings_all.jsonl.gz"
+        )
+        manifests["supervisions"].to_file(
+            output_dir / "cslu_kids_supervisions_all.jsonl.gz"
+        )
 
     return manifests
