@@ -22,7 +22,7 @@ from lhotse import (
     validate_recordings_and_supervisions,
 )
 from lhotse.recipes.utils import manifests_exist, read_manifests_if_cached
-from lhotse.utils import Pathlike, urlretrieve_progress
+from lhotse.utils import Pathlike, safe_extract, urlretrieve_progress
 
 LIBRITTS = (
     "dev-clean",
@@ -74,7 +74,7 @@ def download_libritts(
             )
         shutil.rmtree(part_dir, ignore_errors=True)
         with tarfile.open(tar_path) as tar:
-            tar.extractall(path=target_dir)
+            safe_extract(tar, path=target_dir)
         completed_detector.touch()
 
     return target_dir
