@@ -160,8 +160,12 @@ def prepare_timit(
                 validate_recordings_and_supervisions(recording_set, supervision_set)
 
                 if output_dir is not None:
-                    supervision_set.to_json(output_dir / f"supervisions_{part}.json")
-                    recording_set.to_json(output_dir / f"recordings_{part}.json")
+                    supervision_set.to_file(
+                        output_dir / f"timit_supervisions_{part}.jsonl.gz"
+                    )
+                    recording_set.to_file(
+                        output_dir / f"timit_recordings_{part}.jsonl.gz"
+                    )
 
                 manifests[part] = {
                     "recordings": recording_set,
